MessageContent class

Each message in the chat class

Constructors

MessageContent({required String? senderId, required String? msg, DateTime? dateTime})

Properties

dateTime → DateTime?
final
hashCode → int
The hash code for this object.
no setteroverride
msg → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → String?
final

Methods

isImage() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic> messageMap) → MessageContent
fromJsonList(List<Map<String, dynamic>> messagesMap) → List<MessageContent>