ZipUtils class

Constructors

ZipUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

androidUnzip(String zipPath, [Directory? destination]) → Future<bool>
Android content provider uri has to be copied to a local file first
iosUnzip(String zipPath, [Directory? destination]) → Future<bool>
iOS has to resolve with file://
readFile(String fileName) → Future<List<String>>
Read the txt file inside the extracted zip file